@@ -141,7 +141,7 @@ class CADModel():
                         self.def_file.close()
                         raise
 
-                    if type(test_out) == str or type(test_out) == unicode:
+                    if type(test_out) in [str,bytes]:
                         self.usermodule = usermodule
                     else:
                         self.def_file.close()
@@ -444,7 +444,7 @@ class CADModel():
             elif feature in self.features.keys():
                 self.features[feature].set_colour(self.features[feature].default_colour)
             else:
-                raise ValueError('Unknown feature "{:s}"!'.format(requested))
+                raise ValueError('Unknown feature "{:s}"!'.format(feature))
 
 
 
@@ -596,7 +596,7 @@ class CADModel():
         
             appender.Update()
 
-            self.cell_locator = vtk.vtkCellLocator()
+            self.cell_locator = vtk.vtkStaticCellLocator()
             self.cell_locator.SetTolerance(1e-6)
             self.cell_locator.SetDataSet(appender.GetOutput())
             self.cell_locator.BuildLocator()
@@ -854,6 +854,11 @@ class ModelFeature():
 
             self.polydata = scaler.GetOutput()
 
+            # Remove all the lines from the PolyData. As far as I can tell for "normal" mesh files this shouldn't
+            # remove anything visually important, but it avoids running in to issues with vtkFeatureEdges trying to allocate
+            # way too much memory in VTK 9.1+.
+            self.polydata.SetLines(vtk.vtkCellArray())
+
             if self.parent.status_callback is not None:
                 self.parent.status_callback(None)
 
