@@ -123,7 +123,7 @@ def find_pointpairs(ref_image,image):
 
 def detect_movement(ref,moved):
     """
-    Attempt to auto-detect image movement between two images and return a
+    Attempt to auto-detect image movement between two images using sparse optical flow and return a
     MovementCorrection object representing the movement. If the movement cannot
     be successfully determined, raises calcam.movement.DetectionFailedError
 
@@ -142,6 +142,10 @@ def detect_movement(ref,moved):
 
         MovementCorrection : Movement correction object representing the movement correction.
 
+    Raises:
+
+        DetectionFailedError
+
     """
     if isinstance(ref,Calibration):
         ref_im = ref.get_image(coords='Display')
@@ -164,7 +168,7 @@ def detect_movement(ref,moved):
     m = np.matrix(cv2.cv2.estimateAffinePartial2D(new_points, ref_points)[0])
 
     if m[0, 0] is None:
-        raise DetectionFailedError('Could not determine image movement from automatically. Consider using manual movement correction instead.')
+        raise DetectionFailedError('Could not determine image movement automatically. Consider using manual movement correction instead.')
 
     mov_correction = MovementCorrection(m, ref_im.shape[:2], ref_points, new_points,'Auto-generated by {:s} on {:s} at {:s}'.format(misc.username, misc.hostname, misc.get_formatted_time()))
 
@@ -235,7 +239,40 @@ def manual_movement(ref,moved,correction=None,parent_window=None):
         return correction
 
 
-def phase_correlation_movement(ref_im,moved_im):
+def phase_correlation_movement(ref,moved):
+    """
+    Attempt to auto-detect a simple rigid translation of an image relative to a reference image
+    using Phase Correlation and return a MovementCorrection object representing the movement.
+
+    Parameters:
+
+        ref (np.ndarray or calcam.Calibration)    : Reference image or calibration to align to. This can \
+                                                    be either an array containg a refrence image, or a \
+                                                    calcam calibrationn containing an image.
+
+        moved (np.ndarray or calcam.Calibration) : Moved image or calibration to align. This can \
+                                                    be either an array containg a refrence image, or a \
+                                                    calcam calibrationn containing an image.
+
+
+    Returns:
+
+        MovementCorrection : Movement correction object representing the movement correction.
+
+    Raises:
+
+        DetectionFailedError
+
+    """
+    if isinstance(ref,Calibration):
+        ref_im = ref.get_image(coords='Display')
+    else:
+        ref_im = ref
+
+    if isinstance(moved,Calibration):
+        moved_im = moved.get_image(coords='Display')
+    else:
+        moved_im = moved
 
     ref_x = np.linspace(0,ref_im.shape[1],4)
     ref_y = np.linspace(0,ref_im.shape[0],4)
@@ -253,6 +290,9 @@ def phase_correlation_movement(ref_im,moved_im):
 
     movxy, c = cv2.phaseCorrelate(np.float32(ref_im), np.float32(moved_im))
 
+    if c < 0.2:
+        raise DetectionFailedError('Could not determine image movement from automatically: correlation coefficient too small ({:.2f}). Consider using manual movement correction instead.'.format(c))
+
     new_points = np.zeros_like(ref_points)
     new_points[:,0] = ref_points[:,0] + movxy[0]
     new_points[:,1] = ref_points[:,1] + movxy[1]
@@ -619,4 +659,7 @@ class MovementCorrection:
 
 
 class DetectionFailedError(Exception):
+    """
+    Exception raised if the automatic image movement detection fails to determine the image movement with sufficient confidence or quality.
+    """
     pass
